@@ -54,10 +54,10 @@ struct {
   { "Composer", "BRENT FOX", 0, 0, NULL, NULL, 0 },
   { "Caterer", "PHIL KNIRSCH", 0, 0, NULL, NULL, 0 },
   { "Terminal Velocity", "NALIN DAHYABHAI", 0, 0, NULL, NULL, 0 },
-  { "Boom Operator", "HARALD HOYER", 0, 0, NULL, NULL, 0 },
+  { "Neat Guy #1", "HARALD HOYER", 0, 0, NULL, NULL, 0 },
   { "Standards and Practices", "MATT WILSON", 0, 0, NULL, NULL, 0 },
   { "Kung Fu Choreographer", "THAN NGO", 0, 0, NULL, NULL, 0 },
-  { "CG Artist / Programmer", "BERNHARD ROSENKRÄNZER", 0, 0, NULL, NULL, 0 },
+  { "Bero's Stunt Double", "THOMAS WÖRNER", 0, 0, NULL, NULL, 0 },
   { "Norwegian Møøse Trainer", "TROND EIVIND GLOMSRØD", 0, 0, NULL, NULL, 0 },
   { "Cultural Attaché", "JONATHAN BLANDFORD", 0, 0, NULL, NULL, 0 },
   { "Stunt Double", "KARSTEN HOPP", 0, 0, NULL, NULL, 0 },
